==> chromium_88.0.4324.96.orig.tar.xz: chromium-88.0.4324.96/chrome/browser/memory/chrome_browser_main_extra_parts_memory.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_MEMORY_CHROME_BROWSER_MAIN_EXTRA_PARTS_MEMORY_H_
#define CHROME_BROWSER_MEMORY_CHROME_BROWSER_MAIN_EXTRA_PARTS_MEMORY_H_

#include <memory>

#include "base/macros.h"
#include "chrome/browser/chrome_browser_main_extra_parts.h"

#if defined(OS_CHROMEOS)
namespace chromeos {
namespace memory {
class SystemMemoryPressureEvaluator;
}
}  // namespace chromeos
#endif

namespace memory {
class EnterpriseMemoryLimitPrefObserver;
}  // namespace memory

// Wrapper that owns and initialize the browser memory-related extra parts.
class ChromeBrowserMainExtraPartsMemory : public ChromeBrowserMainExtraParts {
 public:
  ChromeBrowserMainExtraPartsMemory();
  ~ChromeBrowserMainExtraPartsMemory() override;

 private:
  // ChromeBrowserMainExtraParts overrides.
  void PostBrowserStart() override;
  void PostMainMessageLoopRun() override;

  // Tracks changes to the MemoryLimitMbEnabled enterprise policy, and
  // starts/stops the EnterpriseMemoryLimitEvaluator accordingly.
  //
  // Only supported on some platforms, see
  // EnterpriseMemoryLimitPrefObserver::PlatformIsSupported for the list of
  // supported platforms.
  std::unique_ptr<memory::EnterpriseMemoryLimitPrefObserver>
      memory_limit_pref_observer_;

#if defined(OS_CHROMEOS)
  std::unique_ptr<chromeos::memory::SystemMemoryPressureEvaluator>
      cros_evaluator_;
#endif

  DISALLOW_COPY_AND_ASSIGN(ChromeBrowserMainExtraPartsMemory);
};

#endif  // CHROME_BROWSER_MEMORY_CHROME_BROWSER_MAIN_EXTRA_PARTS_MEMORY_H_

==> chromium_90.0.4430.93.orig.tar.xz: chromium-90.0.4430.93/chrome/browser/memory/chrome_browser_main_extra_parts_memory.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_MEMORY_CHROME_BROWSER_MAIN_EXTRA_PARTS_MEMORY_H_
#define CHROME_BROWSER_MEMORY_CHROME_BROWSER_MAIN_EXTRA_PARTS_MEMORY_H_

#include <memory>

#include "base/macros.h"
#include "build/chromeos_buildflags.h"
#include "chrome/browser/chrome_browser_main_extra_parts.h"

#if BUILDFLAG(IS_CHROMEOS_ASH)
namespace chromeos {
namespace memory {
class SystemMemoryPressureEvaluator;
}
}  // namespace chromeos
#endif

namespace memory {
class EnterpriseMemoryLimitPrefObserver;
}  // namespace memory

// Wrapper that owns and initialize the browser memory-related extra parts.
class ChromeBrowserMainExtraPartsMemory : public ChromeBrowserMainExtraParts {
 public:
  ChromeBrowserMainExtraPartsMemory();
  ~ChromeBrowserMainExtraPartsMemory() override;

 private:
  // ChromeBrowserMainExtraParts overrides.
  void PostBrowserStart() override;
  void PostMainMessageLoopRun() override;

  // Tracks changes to the MemoryLimitMbEnabled enterprise policy, and
  // starts/stops the EnterpriseMemoryLimitEvaluator accordingly.
  //
  // Only supported on some platforms, see
  // EnterpriseMemoryLimitPrefObserver::PlatformIsSupported for the list of
  // supported platforms.
  std::unique_ptr<memory::EnterpriseMemoryLimitPrefObserver>
      memory_limit_pref_observer_;

#if BUILDFLAG(IS_CHROMEOS_ASH)
  std::unique_ptr<chromeos::memory::SystemMemoryPressureEvaluator>
      cros_evaluator_;
#endif

  DISALLOW_COPY_AND_ASSIGN(ChromeBrowserMainExtraPartsMemory);
};

#endif  // CHROME_BROWSER_MEMORY_CHROME_BROWSER_MAIN_EXTRA_PARTS_MEMORY_H_
